diff libpurple/eventloop.h @ 18006:f2d8658b3a86

merge of '62e9d17cd37551991c5040ce6ca48e6d7578dde3' and '87c1ea9b3d60a343bac2a35e1fd8f7fee6bda6f2'
author Richard Laager <rlaager@wiktel.com>
date Sat, 19 May 2007 21:38:47 +0000
parents 516f14bef90e
children f22986db6e70
line wrap: on
line diff
--- a/libpurple/eventloop.h	Sat May 19 08:12:31 2007 +0000
+++ b/libpurple/eventloop.h	Sat May 19 21:38:47 2007 +0000
@@ -48,12 +48,18 @@
 struct _PurpleEventLoopUiOps
 {
 	/**
 	 * Creates a callback timer.
 	 * @see g_timeout_add, purple_timeout_add
 	 **/
 	guint (*timeout_add)(guint interval, GSourceFunc function, gpointer data);
 
 	/**
+	 * Creates a callback timer with an interval measured in seconds.
+	 * @see g_timeout_add_seconds, purple_timeout_add_seconds
+	 **/
+	guint (*timeout_add_seconds)(guint interval, GSourceFunc function, gpointer data);
+
+	/**
 	 * Removes a callback timer.
 	 * @see purple_timeout_remove, g_source_remove
 	 */
@@ -48,12 +48,18 @@
 {
 	/**
-	 * Creates a callback timer.
+	 * Creates a callback timer with an interval measured in milliseconds.
 	 * @see g_timeout_add, purple_timeout_add
 	 **/